Struct sampled_data_duration::MixedRateDuration[][src]

pub struct MixedRateDuration { /* fields omitted */ }

Represents a duration of a collection of datasets which may have been sampled at different rates.

Examples

Consider an audio playlist which at first consists of a single audio file of 12345678 samples per channel recorded with at 44.1kHz sampling frequency. We then add another audio file to this playlist which is recorded at 96kHz.

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mut mrd = MixedRateDuration::from(ConstantRateDuration::new(12345678, 48000));

// Note that the default string representation when there is only
// a single sampling rate is of the form `hh:mm:ss;samples`.
assert_eq!(mrd.to_string(), "00:04:17;9678");

// Now we add a 96kHz file
let crd = ConstantRateDuration::new(31415926, 96000);
assert_eq!(crd.to_string(), "00:05:27;23926");

mrd += crd;

// Note that the default string representation when there are
// multiple sampling rates is of the form `hh:mm:ss.s`.
assert_eq!(mrd.to_string(), "00:09:44.450854166");

Implementations

impl MixedRateDuration[src]

pub fn new() -> MixedRateDuration[src]

Construct an empty MixedRateDuration.

Examples

use sampled_data_duration::MixedRateDuration;

let mut mrd = MixedRateDuration::new();

assert_eq!(mrd.to_string(), "00:00:00");

pub fn as_secs(&self) -> u64[src]

Returns the number of whole seconds contained by this MixedRateDuration.

The returned value does not include the fractional part of the duration which can be obtained with subsec_secs.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 * 62 + 123, 48000));
assert_eq!(mrd.to_string(), "00:01:02;123");
assert_eq!(mrd.as_secs(), 62);

pub fn as_mins(&self) -> u64[src]

Returns the number of whole minutes contained by this MixedRateDuration.

The returned value does not include the fractional part of the duration, and can be a value greater than 59.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 * 60 * 91, 48000));
assert_eq!(mrd.to_string(), "01:31:00;0");
assert_eq!(mrd.as_mins(), 91);

pub fn as_hours(&self) -> u64[src]

Returns the number of whole hours contained by this MixedRateDuration.

The returned value does not include the fractional part of the duration, and can be a value greater than 23.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 * 60 * 60 * 48 + 12345, 48000));
assert_eq!(mrd.to_string(), "48:00:00;12345");
assert_eq!(mrd.as_hours(), 48);

pub fn as_days(&self) -> u64[src]

Returns the number of whole days contained by this MixedRateDuration.

The returned value does not include the fractional part of the duration, and can be a value greater than 6.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 * 60 * 60 * 48 + 12345, 48000));
assert_eq!(mrd.to_string(), "48:00:00;12345");
assert_eq!(mrd.as_days(), 2);

pub fn as_weeks(&self) -> u64[src]

Returns the number of whole weeks contained by this MixedRateDuration.

The returned value does not include the fractional part of the duration.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 * 60 * 60 * 24 * 21 + 12345, 48000));
assert_eq!(mrd.to_string(), "504:00:00;12345");
assert_eq!(mrd.as_weeks(), 3);

pub fn num_rates(&self) -> usize[src]

Return the number of different sampling rates used in this MixedRateDuration.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mut mrd = MixedRateDuration::from(ConstantRateDuration::new(1, 44100));
assert_eq!(mrd.num_rates(), 1);

mrd += ConstantRateDuration::new(1, 48000);
assert_eq!(mrd.num_rates(), 2);

mrd += ConstantRateDuration::new(1, 96000);
assert_eq!(mrd.num_rates(), 3);

mrd += ConstantRateDuration::new(2, 44100);
assert_eq!(mrd.num_rates(), 3);

pub fn subsec_nanos(&self) -> u32[src]

Returns the whole number of nanoseconds in the fractional part of this MixedRateDuration.

The returned value will always be less than one second i.e. > 1_000_000_000 nanoseconds.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 + 24000, 48000));
assert_eq!(mrd.to_string(), "00:00:01;24000");
assert_eq!(mrd.subsec_nanos(), 500_000_000);

pub fn subsec_secs(&self) -> f64[src]

Returns the whole number of seconds in the fractional part of this MixedRateDuration.

The returned value will always be less than one second i.e. 0.0 <= subsec_secs < 1.0.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 + 24000, 48000));
assert_eq!(mrd.to_string(), "00:00:01;24000");
assert_eq!(mrd.subsec_secs(), 0.5);

pub fn submin_secs(&self) -> u64[src]

Returns the whole number of seconds left over when this duration is measured in minutes.

The returned value will always be 0 <= submin_secs <= 59.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 * 65 + 32000, 48000));
assert_eq!(mrd.to_string(), "00:01:05;32000");
assert_eq!(mrd.submin_secs(), 5);

pub fn subhour_mins(&self) -> u64[src]

Returns the whole number of minutes left over when this duration is measured in hours.

The returned value will always be 0 <= subhour_mins <= 59.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 * 60 * 68, 48000));
assert_eq!(mrd.to_string(), "01:08:00;0");
assert_eq!(mrd.subhour_mins(), 8);

pub fn subday_hours(&self) -> u64[src]

Returns the whole number of hours left over when this duration is measured in days.

The returned value will always be 0 <= subday_hours <= 23.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 * 60 * 60 * 25, 48000));
assert_eq!(mrd.to_string(), "25:00:00;0");
assert_eq!(mrd.subday_hours(), 1);

pub fn subweek_days(&self) -> u64[src]

Returns the whole number of days left over when this duration is measured in weeks.

The returned value will always be 0 <= subweek_days <= 6.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 * 60 * 60 * 24 * 9, 48000));
assert_eq!(mrd.to_string(), "216:00:00;0");
assert_eq!(mrd.subweek_days(), 2);

pub fn to_duration(&self) -> Duration[src]

Return this MixedRateDuration as a std::time::Duration.

Example

use sampled_data_duration::ConstantRateDuration;
use sampled_data_duration::MixedRateDuration;

let mrd = MixedRateDuration::from(ConstantRateDuration::new(48000 * 42, 48000));
assert_eq!(mrd.to_string(), "00:00:42;0");
assert_eq!(mrd.to_duration().as_secs_f64(), 42.0);